@@ -59,12 +59,13 @@ class DSMREntity(object):
     # used for normal rate.
     if value == '0002':
       return 'normal'
-    if value == '0001':
+    elif value == '0001':
       return 'low'
-
-    return None
+    else:
+      return None
 
 class DSMRReader():
+
     def __init__(self, device = '/dev/ttyUSB0', serial_settings = SERIAL_SETTINGS_V2_2, telegram_specification = telegram_specifications.V2_2, debug=False):
         self.device                 = device
         self.serial_settings        = serial_settings
@@ -216,6 +217,26 @@ class DSMRReader():
         # self.devices = [DSMREntity(name, obis) for name, obis in self.obis_mapping]
         self.devices = [DSMREntity(name, obis) for name, obis in self.obis_mapping_json]
 
+    def format_telegram(self, telegram):
+      '''
+      Transform telegram to json
+      '''
+      body = dict(
+        current_electricity_usage = float(telegram[obis_ref.CURRENT_ELECTRICITY_USAGE].value),
+        current_electricity_delivery = float(telegram[obis_ref.CURRENT_ELECTRICITY_DELIVERY].value),
+        electricity_active_tariff = int(telegram[obis_ref.ELECTRICITY_ACTIVE_TARIFF].value),
+        electricity_used_tariff_1 = float(telegram[obis_ref.ELECTRICITY_USED_TARIFF_1].value),
+        electricity_used_tariff_2 = float(telegram[obis_ref.ELECTRICITY_USED_TARIFF_2].value),
+        electricity_delivered_tariff_1 = float(telegram[obis_ref.ELECTRICITY_DELIVERED_TARIFF_1].value),
+        electricity_delivered_tariff_2 = float(telegram[obis_ref.ELECTRICITY_DELIVERED_TARIFF_2].value),
+        gas_meter_reading = float(telegram[obis_ref.GAS_METER_READING].value)
+      )
+
+      if self.device:
+          print(body)
+
+      return json.dumps(body)
+
     def __update_entities_telegram(self, telegram):
         '''
         Update entities with latest telegram and trigger state update.
@@ -233,12 +254,13 @@ class DSMRReader():
           if self.debug:
             print('>> Reading DSMR in debug mode') 
 
+          t = dict()
+
           for telegram in self.serial_reader.read_as_object():
-            os.system('clear')
+            # now, translate telegram to dict
+            obj = self.format_telegram(telegram)
 
-            # [attr for attr, value in telegram]
-
-            print(telegram)
+            # do something with 'obj'
             
 
           # for telegram in self.serial_reader.read():
